SymSpell

Struct SymSpell 

pub struct SymSpell<T: StringStrategy> { /* private fields */ }

Implementations

Source

impl<T: StringStrategy> SymSpell<T>

pub fn load_dictionary( &mut self, corpus: &str, term_index: i64, count_index: i64, separator: &str, ) -> bool

Load multiple dictionary entries from a file of word/frequency count pairs.

Arguments
  • corpus - The path+filename of the file.
  • term_index - The column position of the word.
  • count_index - The column position of the frequency count.
  • separator - Separator between word and frequency
pub fn load_dictionary_line( &mut self, line: &str, term_index: i64, count_index: i64, separator: &str, ) -> bool

Load single dictionary entry from word/frequency count pair.

Arguments
  • line - word/frequency pair.
  • term_index - The column position of the word.
  • count_index - The column position of the frequency count.
  • separator - Separator between word and frequency
pub fn load_bigram_dictionary( &mut self, corpus: &str, term_index: i64, count_index: i64, separator: &str, ) -> bool

Load multiple bigram entries from a file of bigram/frequency count pairs.

Arguments
  • corpus - The path+filename of the file.
  • term_index - The column position of the word.
  • count_index - The column position of the frequency count.
  • separator - Separator between word and frequency
pub fn load_bigram_dictionary_line( &mut self, line: &str, term_index: i64, count_index: i64, separator: &str, ) -> bool

Load single dictionary entry from bigram/frequency count pair.

Arguments
  • line - bigram/frequency pair.
  • term_index - The column position of the word.
  • count_index - The column position of the frequency count.
  • separator - Separator between word and frequency
pub fn lookup( &self, input: &str, verbosity: Verbosity, max_edit_distance: i64, ) -> Vec<Suggestion>

Find suggested spellings for a given input word, using the maximum edit distance specified during construction of the SymSpell dictionary.

Arguments
  • input - The word being spell checked.
  • verbosity - The value controlling the quantity/closeness of the retuned suggestions.
  • max_edit_distance - The maximum edit distance between input and suggested words.
Examples
use symspell::{SymSpell, AsciiStringStrategy, Verbosity};

let mut symspell: SymSpell<AsciiStringStrategy> = SymSpell::default();
symspell.load_dictionary("data/frequency_dictionary_en_82_765.txt", 0, 1, " ");
symspell.lookup("whatver", Verbosity::Top, 2);
pub fn lookup_compound( &self, input: &str, edit_distance_max: i64, ) -> Vec<Suggestion>

Find suggested spellings for a given input sentence, using the maximum edit distance specified during construction of the SymSpell dictionary.

Arguments
  • input - The sentence being spell checked.
  • max_edit_distance - The maximum edit distance between input and suggested words.
Examples
use symspell::{SymSpell, AsciiStringStrategy};

let mut symspell: SymSpell<AsciiStringStrategy> = SymSpell::default();
symspell.load_dictionary("data/frequency_dictionary_en_82_765.txt", 0, 1, " ");
symspell.lookup_compound("whereis th elove", 2);
pub fn word_segmentation( &self, input: &str, max_edit_distance: i64, ) -> Composition

Divides a string into words by inserting missing spaces at the appropriate positions

Arguments
  • input - The word being segmented.
  • max_edit_distance - The maximum edit distance between input and suggested words.
Examples
use symspell::{SymSpell, UnicodeStringStrategy, Verbosity};

let mut symspell: SymSpell<UnicodeStringStrategy> = SymSpell::default();
symspell.load_dictionary("data/frequency_dictionary_en_82_765.txt", 0, 1, " ");
symspell.word_segmentation("itwas", 2);